@@ -29,12 +29,12 @@
 #include "libkita/category.h"
 
 
-KitaBoardView::KitaBoardView(QWidget *parent, const char *name)
+KitaBoardView::KitaBoardView( QWidget *parent, const char *name )
     : KitaBoardViewBase(parent, name)
 {
-  m_boardList->setSorting(-1);
-  m_boardList->addColumn("name");
-  connect(m_boardList, SIGNAL(executed(QListViewItem*)), SLOT( loadBoard(QListViewItem*) ));
+  m_boardList->setSorting( -1 );
+  m_boardList->addColumn( "name" );
+  connect( m_boardList, SIGNAL( executed( QListViewItem* ) ), SLOT( loadBoard( QListViewItem* ) ) );
   connect( m_boardList, SIGNAL( contextMenuRequested( QListViewItem*, const QPoint&, int ) ),
                         SLOT( slotContextMenuRequested( QListViewItem*, const QPoint&, int ) ) );
 }
@@ -42,26 +42,26 @@ KitaBoardView::KitaBoardView(QWidget *parent, const char *name)
 KitaBoardView::~KitaBoardView()
 {}
 
-QString KitaBoardView::getCategory(const QString& line) const
+QString KitaBoardView::getCategory( const QString& line ) const
 {
-  QRegExp regexp("<BR><BR><B>(.*)</B><BR>", false);
-  if(regexp.search(line) != -1) {
+  QRegExp regexp( "<BR><BR><B>(.*)</B><BR>", false );
+  if(regexp.search( line ) != -1) {
     return regexp.cap(1);
   } else {
     return QString::null;
   }
 }
 
-Kita::Board KitaBoardView::getBoard(const QString& line) const
+Kita::Board* KitaBoardView::getBoard( const QString& line ) const
 {
-  QRegExp regexp("<A HREF=(.*)>(.*)</A>", false);
+  QRegExp regexp( "<A HREF=(.*)>(.*)</A>", false );
   if( regexp.search(line) != -1 ) {
     QString board_url = regexp.cap(1);
     QString board_title = regexp.cap(2);
     Kita::Board::setName( board_url, board_title );
-    return Kita::Board(board_url, board_title);
+    return Kita::Board::getByURL( board_url );
   } else {
-    return Kita::Board( "" );
+    return Kita::Board::getByURL( QString::null );
   }
 }
 
@@ -84,7 +84,7 @@ bool KitaBoardView::isBoardUrl(const KURL& url) const
 void KitaBoardView::loadBoardList()
 {
   QString tmpFile;
-  QString url = "http://www.ff.iij4u.or.jp/~ch2/bbsmenu.html";
+  QString url = KitaConfig::boardListURL();
   if( ! KIO::NetAccess::download(url, tmpFile) )
   {
     return;
@@ -105,33 +105,31 @@ void KitaBoardView::loadBoardList()
   m_boardList->clear();
 
   KListViewItem* previous = 0;
-  for(Kita::Category* category = categoryList.first(); category; category = categoryList.next())
+  for( Kita::Category* category = categoryList.first(); category; category = categoryList.next() )
   {
-    QValueList<Kita::Board> board_list = category->getBoardList();
+    QPtrList<Kita::Board> board_list = category->getBoardList();
 
     if( board_list.isEmpty() ) {
       continue;
     }
 
-    KListViewItem* categoryItem = new KListViewItem(m_boardList, previous, category->name());
+    KListViewItem* categoryItem = new KListViewItem( m_boardList, previous, category->name() );
 
     KListViewItem* previousBoard = 0;
-    for(QValueListIterator<Kita::Board> it = board_list.begin(); it != board_list.end(); ++it)
+    QPtrListIterator<Kita::Board> it( board_list );
+    for(; *it; ++it)
     {
-      Kita::Board board = (*it);
-      previousBoard = new KListViewItem(categoryItem, previousBoard, board.name(), board.url());
+      Kita::Board* board = *it;
+      previousBoard = new KListViewItem( categoryItem, previousBoard, board->name(), board->url() );
     }
     previous = categoryItem;
   }
 }
 
-QPtrList<Kita::Category> KitaBoardView::getCategoryList(const QString& html) const
+QPtrList<Kita::Category> KitaBoardView::getCategoryList( const QString& html ) const
 {
   QPtrList<Kita::Category> result;
 
-  // XXX: maybe crash 
-  //  result.setAutoDelete( true );
-
   QStringList lines = QStringList::split("\n", html);
   QStringList::iterator it;
 
@@ -139,38 +137,21 @@ QPtrList<Kita::Category> KitaBoardView::getCategoryList(const QString& html) con
   for(it = lines.begin(); it != lines.end(); ++it) {
     QString category_name = getCategory(*it);
     if( category_name != QString::null ) {
-      current_category = new Kita::Category(category_name);
-      result.append(current_category);
+      current_category = new Kita::Category( category_name );
+      result.append( current_category );
     } else {
-      Kita::Board board = getBoard(*it);
+      Kita::Board* board = getBoard(*it);
 
-      if( isBoardUrl(board.url()) ) {
+      if( isBoardUrl( board->url() ) ) {
         if( current_category ) {
-          current_category->append(board);
+          current_category->append( board );
         }
       }
     }
   }
-//  printCateogryList(result);
   return result;
 }
 
-void KitaBoardView::printCateogryList(QPtrList<Kita::Category>& list)
-{
-  Kita::Category* category;
-  for(category = list.first(); category; category = list.next()) {
-    if(category->name() == QString::null) continue;
-
-    QValueList<Kita::Board> board_list = category->getBoardList();
-    QValueListIterator<Kita::Board> it2;
-    for(it2 = board_list.begin(); it2 != board_list.end(); ++it2) {
-      kdDebug() << "category:" << category->name()
-      << "name:" << (const char*)(*it2).name()
-      << "url:" << (*it2).url() << endl;
-    }
-  }
-}
-
 void KitaBoardView::loadBoard( QListViewItem* item )
 {
   QString boardName = item->text(0);
@@ -180,7 +161,7 @@ void KitaBoardView::loadBoard( QListViewItem* item )
     return;
   }
 
-  Kita::Board board( url, boardName );
+  Kita::Board* board = Kita::Board::getByURL( url );
   emit clicked( board );
 }
 
