@@ -31,10 +31,10 @@ KitaSubjectTabWidget::~KitaSubjectTabWidget()
 {
 }
 
-void KitaSubjectTabWidget::loadBoard( const Kita::Board& board )
+void KitaSubjectTabWidget::loadBoard( const Kita::Board* board )
 {
   m_latestView->loadBoard( board );
-  setTabLabel( m_latestView, board.name() );
+  setTabLabel( m_latestView, board->name() );
 }
 
 void KitaSubjectTabWidget::updateThread( const Kita::Thread& thread )
