@@ -33,12 +33,12 @@ public:
 
 public slots:
   void reloadSubject();
-  void loadBoard( const Kita::Board& board );
+  void loadBoard( const Kita::Board* board );
   void setFont( const QFont& font );
   void updateThread( const Kita::Thread& thread );
 
 private:
-  Kita::Board m_board;
+  const Kita::Board* m_board;
   QStringList m_prevquery;
   unsigned m_nextHitIndex;
   QValueList<KListViewItem*> m_hitList;
