@@ -21,6 +21,7 @@
 #include <qclipboard.h>
 #include <qapplication.h>
 #include <qmessagebox.h>
+#include <qregexp.h>
 
 #define MAX_TABLABEL_LEN 20
 
@@ -32,16 +33,12 @@ KitaThreadTabWidget::KitaThreadTabWidget(QWidget *parent, const char *name, WFla
                      SLOT( deleteView( KitaThreadView* ) ) );
 
   KGlobal::locale()->insertCatalogue( "kitapart" );
-  KLibFactory* factory = KLibLoader::self()->factory( "libkitapart" );
-  if( ! factory ) {
-    QMessageBox::critical( parent, i18n( "Load Error" ),
-                                   i18n( "can't load libkitapart." ) );
-    return;
+  KitaThreadView* view = createView();
+
+  if( view ) {
+    addTab( view, "thread" );
+    connectSignals( view );
   }
-  KitaThreadPart* part = static_cast<KitaThreadPart *>( factory->create( this, "thread", "KitaThreadPart" ) );
-  KitaThreadView* view = static_cast<KitaThreadView *>( part->widget() );
-  addTab( view, "thread" );
-  connectSignals( view );
 }
 
 KitaThreadTabWidget::~KitaThreadTabWidget()
@@ -52,30 +49,51 @@ void KitaThreadTabWidget::showThread( const Kita::Thread& thread )
 {
   // TODO: 줬ɤΥ֤ˤǤˤȤϤȤ
   static_cast<KitaThreadView *>( currentPage() )->showThread( thread );
+
+  // FIXME: showThreadWithNewTab()إԡ
   setTabLabel( currentPage(), thread.name().left( MAX_TABLABEL_LEN ) );
   setTabToolTip( currentPage(), thread.name() );
 }
 
-void KitaThreadTabWidget::showThreadWithNewTab( const Kita::Thread& thread )
+KitaThreadView* KitaThreadTabWidget::createView()
 {
   KLibFactory* factory = KLibLoader::self()->factory( "libkitapart" );
   if( ! factory ) {
-    return;
+    QMessageBox::critical( parentWidget(),
+                           i18n( "Load Error" ),
+                           i18n( "can't load libkitapart." ) );
+    return 0;
   }
   KitaThreadPart* part = static_cast<KitaThreadPart *>( factory->create( this, "thread", "KitaThreadPart" ) );
   KitaThreadView* view = static_cast<KitaThreadView *>( part->widget() );
-  addTab( view, thread.name().left( MAX_TABLABEL_LEN ) );
-  setTabToolTip( view, thread.name() );
 
-  connectSignals( view );
-  view->showThread( thread );
-  showPage( view );
+  return view;
+}
+
+void KitaThreadTabWidget::showThreadWithNewTab( const Kita::Thread& thread )
+{
+  KitaThreadView* view = createView();
+
+  if( view ) {
+    addTab( view, thread.name().left( MAX_TABLABEL_LEN ) );
+    setTabToolTip( view, thread.name() );
+
+    connectSignals( view );
+    view->showThread( thread );
+    showPage( view );
+
+    QString threadName = view->threadName();
+
+    // FIXME: showThread()饳ԡ
+    setTabLabel( currentPage(), threadName.left( MAX_TABLABEL_LEN ) );
+    setTabToolTip( currentPage(), threadName );
+  }
 }
 
 void KitaThreadTabWidget::connectSignals( KitaThreadView* view )
 {
   connect( view, SIGNAL( openURLRequest( const KURL&, const KParts::URLArgs& ) ),
-           this, SIGNAL( openURLRequest( const KURL&, const KParts::URLArgs& ) ) );
+           this, SLOT( slotOpenURLRequest( const KURL&, const KParts::URLArgs& ) ) );
   connect( view, SIGNAL( signalChangeStatusbar( const QString& ) ),
            this, SIGNAL( signalChangeStatusbar( const QString& ) ) );
   connect( view, SIGNAL( thread( const Kita::Thread& ) ),
@@ -95,20 +113,29 @@ void KitaThreadTabWidget::deleteView( KitaThreadView* view )
   delete view;
 
   if( count() == 0 ) {
-    // TODO: 󥹥ȥ饯ǤƱåȤäƤ롣
-    KLibFactory* factory = KLibLoader::self()->factory( "libkitapart" );
-    if( ! factory ) {
-      return;
-    }
-    KitaThreadPart* part = static_cast<KitaThreadPart *>( factory->create( this, "thread", "KitaThreadPart" ) );
-    KitaThreadView* view = static_cast<KitaThreadView *>( part->widget() );
-    addTab( view, "thread" );
-    connectSignals( view );
+    KitaThreadView* view = createView();
 
-    showPage( view );
+    if( view ) {
+      addTab( view, "thread" );
+      connectSignals( view );
+
+      showPage( view );
+    }
   }
 }
 
+void KitaThreadTabWidget::slotOpenURLRequest( const KURL& url, const KParts::URLArgs& args )
+{
+    // TODO: URLɤäȸ̩ʥå򤹤뤳
+    QRegExp regexp( "http://([^/]*)/([^/]*)/dat/(.*)\\.dat" );
+    if( regexp.search( url.url() ) == -1 ) {
+        emit openURLRequest( url, args );
+    } else {
+        Kita::Thread thread( url.url() );
+        showThreadWithNewTab( thread );
+    }
+}
+
 KitaThreadTabBar::KitaThreadTabBar( QWidget* parent, const char* name )
  : QTabBar( parent, name )
 {
