@@ -22,6 +22,7 @@
 #include <qdict.h>
 
 #include "kita_misc.h"
+#include "threadinfo.h"
 
 #include "qcp932codec.h"
 
@@ -100,7 +101,8 @@ const QPtrList<Thread> Board::getThreadList() const
         KURL datURL = m_boardURL;
         datURL.addPath("/dat/" + fname);
         Kita::Board::setName( datToBoard( datURL.url() ), name() );
-        Kita::Thread* thread = new Kita::Thread( datURL, subject, num.toInt());
+        Kita::Thread* thread = new Kita::Thread( datURL.url(), subject );
+        KitaThreadInfo::setResNum( datURL.url(), num.toInt() );
         threadList.append(thread);
       }
     }
@@ -123,25 +125,6 @@ const QString Board::toXmlFragment() const
   return ret;
 }
 
-Board Board::fromXml( const QString& xml )
-{
-  Board board;
-
-  BoardXmlParser parser;
-  QXmlSimpleReader reader;
-  QXmlInputSource source;
-  source.setData( xml );
-  reader.setContentHandler( &parser );
-  reader.parse( &source );
-
-  if( parser.isValid() ) {
-    board = parser.getBoard();
-  } else {
-    kdError() << "inValid" << endl;
-  }
-  return board;
-}
-
 Board* Board::getByURL( const QString& boardURL )
 {
     // FIXME: null֥Ȥ׵ΤӤ˺äƤ롣
@@ -213,7 +196,8 @@ bool BoardXmlParser::endElement( const QString&, const QString& localName, const
 {
   if( localName == "board" ) {
     m_inBoard = false;
-    m_board = Kita::Board( m_urlStr, m_nameStr );
+    Kita::Board::setName( m_urlStr, m_nameStr );
+    m_board = Kita::Board::getByURL( m_urlStr );
     m_isValid = true;
     // create board;
   } else if( localName == "url" ) {
