@@ -11,7 +11,7 @@
 #ifndef KITACATEGORY_H
 #define KITACATEGORY_H
 
-#include <qvaluelist.h>
+#include <qptrlist.h>
 
 #include "board.h"
 
@@ -24,12 +24,12 @@ namespace Kita {
 
   class Category{
     QString m_name;
-    QValueList<Board> m_boardList;
+    QPtrList<Board> m_boardList;
   public:
     Category( const QString& name );
     ~Category();
-    void append( const Board& board );
-    const QValueList<Board>& getBoardList() const;
+    void append( const Board* board );
+    const QPtrList<Board>& getBoardList() const;
     const QString& name() const;
   };
 };
