@@ -10,7 +10,7 @@
 #ifndef KITAKITA_MISC_H
 #define KITAKITA_MISC_H
 
-#include <kurl.h>
+#include <qstring.h>
 
 namespace Kita {
 
@@ -18,12 +18,12 @@ namespace Kita {
  * @author Hideki Ikemoto
  */
 
-  KURL datToThread( const KURL& datURL );
-  KURL threadToDat( const KURL& threadURL );
-  KURL boardToSubject( const KURL& boardURL );
-  KURL subjectToBoard( const KURL& subjectURL );
-  QString datToCache( const KURL& datURL );
-  QString datToCache( const KURL& datURL );
+  QString datToBoard( const QString& datURL );
+  QString datToThread( const QString& datURL );
+  QString threadToDat( const QString& threadURL );
+  QString boardToSubject( const QString& boardURL );
+  QString subjectToBoard( const QString& subjectURL );
+  QString datToCache( const QString& datURL );
 };
 
 
