@@ -25,6 +25,7 @@
 #include "board.h"
 #include "kita_misc.h"
 #include "qcp932codec.h"
+#include "threadinfo.h"
 
 using namespace Kita;
 
@@ -34,8 +35,8 @@ Thread::Thread()
 {
 }
 
-Thread::Thread( const KURL& datURL, const QString& threadName, int resNum )
-  : m_datURL( datURL ), m_threadName( threadName ), m_resNum( resNum )
+Thread::Thread( const QString& datURL, const QString& threadName )
+  : m_datURL( datURL ), m_threadName( threadName )
 {
 }
 
@@ -43,7 +44,7 @@ Thread::Thread( const Thread& obj )
 {
   m_datURL = obj.m_datURL;
   m_threadName = obj.m_threadName;
-  m_resNum = obj.m_resNum;
+  setResNum( obj.resNum() );
 }
 
 Thread::~Thread()
@@ -54,29 +55,29 @@ Thread& Thread::operator=( const Thread& obj )
 {
   m_datURL = obj.m_datURL;
   m_threadName = obj.m_threadName;
-  m_resNum = obj.m_resNum;
+  setResNum( obj.resNum() );
 
   return *this;
 }
 
-const KURL& Thread::datURL() const
+const QString& Thread::datURL() const
 {
   return m_datURL;
 }
 
 const QString Thread::url() const
 {
-    return datToThread( m_datURL.url() );
+    return datToThread( m_datURL );
 }
 
 const QString Thread::datID() const
 {
-  return m_datURL.filename().section( ".", 0, 0 );
+  return KURL( m_datURL ).filename().section( ".", 0, 0 );
 }
 
 int Thread::resNum() const
 {
-  return m_resNum;
+    return KitaThreadInfo::resNum( m_datURL );
 }
 
 const QString& Thread::name() const
@@ -84,6 +85,11 @@ const QString& Thread::name() const
   return m_threadName;
 }
 
+void Thread::setResNum( int resNum )
+{
+    KitaThreadInfo::setResNum( m_datURL, resNum );
+}
+
 const QString& Thread::boardName() const
 {
     Board* board = Board::getByURL( boardURL() );
@@ -92,12 +98,12 @@ const QString& Thread::boardName() const
 
 const QString Thread::boardURL() const
 {
-  return datToBoard( m_datURL.url() );
+  return datToBoard( m_datURL );
 }
 
 const QString Thread::boardID() const
 {
-  return KURL( datToBoard( m_datURL.url() ) ).fileName();
+  return KURL( datToBoard( m_datURL ) ).fileName();
 }
 
 const QString Thread::toXmlFragment() const
@@ -105,9 +111,9 @@ const QString Thread::toXmlFragment() const
   QString ret;
 
   ret += "<thread xmlns=\"http://kita.sourceforge.jp/ns/thread\">\n";
-  ret += QString("<daturl>%1</daturl>\n").arg( m_datURL.url() );
+  ret += QString("<daturl>%1</daturl>\n").arg( m_datURL );
   ret += QString("<name>%1</name>\n").arg( m_threadName );
-  ret += QString("<resnum>%1</resnum>\n").arg( m_resNum );
+  ret += QString("<resnum>%1</resnum>\n").arg( resNum() );
 
   // FIXME: Board饹饳ԡ
   ret += "<board xmlns=\"http://kita.sourceforge.jp/ns/board\">\n";
@@ -174,8 +180,6 @@ bool ThreadXmlParser::endElement( const QString& namespaceURI, const QString& lo
   if( localName == "board" ) {
     m_inBoard = false;
     m_boardParser->endElement( namespaceURI, localName, qName );
-    Board board = m_boardParser->getBoard();
-    m_board = new Board( board.url(), board.name() );
 
     delete m_boardParser;
     m_boardParser = 0;
@@ -185,8 +189,8 @@ bool ThreadXmlParser::endElement( const QString& namespaceURI, const QString& lo
     m_boardParser->endElement( namespaceURI, localName, qName );
   } else if( localName == "thread" ) {
     m_inThread = false;
-    Kita::Board::setName( datToBoard( m_datUrlStr ), m_board->name() );
-    m_thread = Kita::Thread( KURL( m_datUrlStr ), m_threadName, m_resNum );
+    m_thread = Kita::Thread( m_datUrlStr, m_threadName );
+    KitaThreadInfo::setResNum( m_datUrlStr, m_resNum );
     m_isValid = true;
     // create thread;
   } else if( localName == "daturl" ) {
@@ -214,9 +218,9 @@ bool ThreadXmlParser::characters( const QString& ch )
 
 QString ThreadAccess::get()
 {
-  if ( m_thread.datURL().protocol() != "k2ch" ) {
+  if ( KURL( m_thread.datURL() ).protocol() != "k2ch" ) {
     KIO::SlaveConfig::self()->setConfigData("http",
-      m_thread.datURL().host(),
+      KURL( m_thread.datURL() ).host(),
       "UserAgent",
       QString( "Monazilla/1.00 (Kita/%1)" ).arg( VERSION ) );
   }
@@ -255,7 +259,7 @@ void ThreadAccess::slotRedirection(KIO::Job *, const KURL & newURL)
 {
   kdDebug() << "Redirected to newURL: " << newURL.url() << endl;
   Kita::Board::setName( datToBoard( newURL.url() ), m_thread.boardName() );
-  m_thread = Kita::Thread( newURL);
+  m_thread = Kita::Thread( newURL.url() );
   emit redirection( newURL.url() );
 }
 
@@ -308,8 +312,9 @@ void ThreadFactory::insertThread( Thread& thread )
     instance = new ThreadFactory();
   }
 
-  Thread* new_thread = new Thread( thread.datURL(), thread.name(), thread.resNum() );
-  instance->m_dict.insert( thread.datURL().url(), new_thread );
+  Thread* new_thread = new Thread( thread.datURL(), thread.name() );
+  KitaThreadInfo::setResNum( thread.datURL(), thread.resNum() );
+  instance->m_dict.insert( thread.datURL(), new_thread );
 }
 
 Thread* ThreadFactory::getThread( QString& datURL )
