@@ -31,22 +31,21 @@ namespace Kita {
 
   class Thread
   {
-    KURL m_datURL;
+    QString m_datURL;
     QString m_threadName;
-    int m_resNum;
   public:
+    Thread( const QString& datURL, const QString& threadName = QString::null );
     Thread();
     Thread( const Thread& obj );
-    Thread( const KURL& datURL, const QString& threadName = QString::null, int resNum = 0 );
     ~Thread();
     Thread& operator=( const Thread& obj );
-    const KURL& datURL() const;
+    const QString& datURL() const;
     const QString url() const;
     const QString datID() const;
     int resNum() const;
     const QString& name() const;
     void setName(const QString& name) { m_threadName = name; }
-    void setResNum(int resNum) { m_resNum = resNum; }
+    void setResNum(int resNum);
     const QString& boardName() const;
     const QString boardURL() const;
     const QString boardID() const;
@@ -72,7 +71,6 @@ namespace Kita {
     QString m_datUrlStr;
     QString m_threadName;
     int m_resNum;
-    Board* m_board;
     Thread m_thread;
     BoardXmlParser* m_boardParser;
 
