@@ -26,6 +26,7 @@ static const char *version = VERSION;
 static KCmdLineOptions options[] =
 {
     { "+[URL]", I18N_NOOP( "Document to open." ), 0 },
+    { "boardlist <boardlist>", I18N_NOOP( "board list's URL." ), "http://www.ff.iij4u.or.jp/~ch2/bbsmenu.html" }, 
     { 0, 0, 0 }
 };
 
@@ -41,6 +42,9 @@ int main(int argc, char **argv)
     // register ourselves as a dcop client
     app.dcopClient()->registerAs(app.name(), false);
 
+    KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
+    KitaConfig::setBoardListURL( QString( args->getOption( "boardlist" ) ) );
+
     // see if we are starting with session management
     if (app.isRestored())
         RESTORE(KitaMainWindow)
