@@ -64,9 +64,7 @@ bool KitaThreadPart::openURL( const KURL& _url )
     connect( m_threadview, SIGNAL( showThreadCompleted(const KURL&) ),
              this, SLOT( slotOpenURLResult() ) );
 
-    Kita::Board board( m_url.upURL().upURL().url() );
-    Kita::Board::setName( board.url(), board.name() );
-    m_threadview->showThread( Kita::Thread( m_url ) );
+    m_threadview->showThread( Kita::Thread( m_url.url() ) );
     emit started( 0 );
     return true;
 }
