@@ -35,7 +35,7 @@
 
 #include "kitahtmlpart.h"
 #include "kitawritedialog.h"
-#include "../kitacacheinfo.h"
+#include "libkita/threadinfo.h"
 #include "kita2ch.h"
 #include "kitaconfig.h"
 
@@ -214,7 +214,9 @@ void KitaThreadView::update( const QString& result )
   text += footer( prevResNum );
   text += "</body></html>";
 
-  m_threadPart->displayContentsAndGotoURL( text, m_thread );
+  m_threadPart->displayContents( text, m_thread.datURL() );
+  // FIXME: ⤦äȤޤȤˡȤ
+  m_threadPart->gotoURL( m_thread, QMIN( prevResNum + 1, m_thread.resNum() ) );
   updateButton();
 
   emit showThreadCompleted( m_thread.url() );
@@ -229,7 +231,7 @@ void KitaThreadView::updateButton()
   if ( HighLightButton->isOn() ) {
     HighLightButton->toggle();
   }
-  if( FavoriteThreads::getInstance()->contains( m_thread.datURL().url() ) ) {
+  if( FavoriteThreads::getInstance()->contains( m_thread.datURL() ) ) {
     BookmarkButton->setOn( true );
   } else {
     BookmarkButton->setOn( false );
@@ -436,8 +438,8 @@ void KitaThreadView::slotOpenURLRequest(const KURL& url, const KParts::URLArgs&
     return;
   }
   KURL datURL = filterReadCGI( url );
-  if ( datURL.host() == m_thread.datURL().host()
-    && datURL.path() == m_thread.datURL().path() )
+  if ( datURL.host() == KURL( m_thread.datURL() ).host()
+    && datURL.path() == KURL( m_thread.datURL() ).path() )
   {
     if ( datURL.hasRef() ) m_threadPart->gotoAnchor( datURL.ref() );
     return;
@@ -454,7 +456,7 @@ KURL KitaThreadView::filterReadCGI(const KURL& url)
 {
   KURL  newURL = url;
   if ( url.path().contains("/test/read.cgi") ) {
-    newURL.setProtocol( m_thread.datURL().protocol() );
+    newURL.setProtocol( KURL( m_thread.datURL() ).protocol() );
     QString tmp = url.path().section("/test/read.cgi", 1);
 
     QString newPath = QString( "/%1/dat/%2.dat" )
