@@ -36,7 +36,7 @@ public:
 
   virtual bool error(){ return false; };
 
-  static KitaWriteDialog * open( const Kita::PostInfo& info );
+  static KitaWriteDialog * open( const Kita::PostInfo& info, const Kita::Thread& thread );
 
 public slots:
   void postMessage();
